==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bi = function () {
        return new PolarLineSeries();
    };
    PolarLineSeries.prototype.get_fi = function () {
        return true;
    };
    PolarLineSeries.prototype.cq = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.acl = a;
    };
    PolarLineSeries.prototype.acj = function (a) {
        var b = a;
        b.da();
    };
    PolarLineSeries.prototype.ack = function (a, b) {
        var c = b;
        c.db(a.m, this.ib);
        this.yw.az(this, this.zo(), runOn(this, this.ye));
        var d = false;
        var e = this.yw.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.aa3(-1, this.za.count, b.q);
        }
        this.yw.ad(b.dd, true, false, true, false);
    };
    PolarLineSeries.prototype.acb = function () {
        return this.acm;
    };
    PolarLineSeries.prototype.q4 = function (a, b, c, d) {
        _super.prototype.q4.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.rm(false);
                this.qg();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acm:aco', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.w1 = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.da = function () {
        this.dd.an = null;
        this.dc.an = null;
        this.as();
    };
    PolarLineSeriesView.prototype.db = function (a, b) {
        this.c9.ab8.d(this.dd, a, b);
        this.as();
    };
    PolarLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dc.an = this.dd.an;
        this.dc._stroke = a;
        this.dc.ad = this.e.ic + 3;
    };
    PolarLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
            }
            else {
                a.t(this.dd);
            }
        }
    };
    PolarLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bb.exportPathData(a, this.dd, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bj = function () {
        return new PolarLineSeries();
    };
    PolarLineSeries.prototype.get_fk = function () {
        return true;
    };
    PolarLineSeries.prototype.cs = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.q1 = function (a) {
        _super.prototype.q1.call(this, a);
        this.acu = a;
    };
    PolarLineSeries.prototype.acs = function (a) {
        var b = a;
        b.da();
    };
    PolarLineSeries.prototype.act = function (a, b) {
        var c = b;
        c.db(a.m, this.id);
        this.y5.az(this, this.zx(), runOn(this, this.yn));
        var d = false;
        var e = this.y5.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.abc(-1, this.zj.count, b.q);
        }
        this.y5.ad(b.dd, true, false, true, false);
    };
    PolarLineSeries.prototype.ack = function () {
        return this.acv;
    };
    PolarLineSeries.prototype.q9 = function (a, b, c, d) {
        _super.prototype.q9.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.rr(false);
                this.ql();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acv:acx', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.xa = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.da = function () {
        this.dd.an = null;
        this.dc.an = null;
        this.as();
    };
    PolarLineSeriesView.prototype.db = function (a, b) {
        this.c9.ach.d(this.dd, a, b);
        this.as();
    };
    PolarLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dc.an = this.dd.an;
        this.dc._stroke = a;
        this.dc.ad = this.e.ie + 3;
    };
    PolarLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
            }
            else {
                a.t(this.dd);
            }
        }
    };
    PolarLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bc.exportPathData(a, this.dd, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };
